MobiOrdt class
Constructors
- MobiOrdt()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- offsetsCount ↔ int
-
getter/setter pair
-
ordt1
↔ List<
int> -
getter/setter pair
- ordt1Pos ↔ int
-
getter/setter pair
-
ordt2
↔ List<
int> -
getter/setter pair
- ordt2Pos ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited