toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'MobiPdbHeader{name: $name, attributes: $attributes, version: $version, creationTime: $creationTime, modificationTime: $modificationTime, backupTime: $backupTime, modificationNumber: $modificationNumber, appInfoOffset: $appInfoOffset, sortInfoOffset: $sortInfoOffset, type: $type, creator: $creator, uid: $uid, nextRecordListOffset: $nextRecordListOffset, recordCount: $recordCount}';
}